@@ -8,11 +8,14 @@
 #' @param  ... Arguments passed to [dplyr::select()] (needs to be at least
 #'   [dplyr::everything()]).
 #' @return A data frame with a new `na_flag` logical variable.
-#' @importFrom dplyr mutate select
+#' @importFrom dplyr select
 #' @importFrom stats complete.cases
 #' @examples
-#' flag_na(dplyr::starwars, gender)
+#' flag_na(dplyr::starwars, hair_color)
 #' @export
 flag_na <- function(data, ...) {
-  dplyr::mutate(data, na_flag = !stats::complete.cases(dplyr::select(data, ...)))
+  sub_data <- dplyr::select(data, ...)
+  nas <- !stats::complete.cases(sub_data)
+  data$na_flag <- nas
+  data
 }
