@@ -4,8 +4,8 @@
 #'
 #' @param n The number of times to run [gc()].
 #' @export
-flush_memory <- function(n = 10) {
-  for (i in 1:n) {
+flush_memory <- function(n = 1) {
+  for (i in seq(n)) {
     suppressMessages(gc(reset = TRUE, full = TRUE))
   }
 }
