@@ -10,8 +10,9 @@
 #'
 #' @param x A character string to normalize.
 #' @param case logical; whether [stringr::str_to_upper()] should be called.
-#' @param punct logical; whether [stringr::str_replace_all()] should be called on punctuation.
-#' @param quote logical; whether [stringr::str_replace_all()] should be called on double quotes.
+#' @param punct character; A character string to replace most punctuation with.
+#' @param quote logical; whether [stringr::str_replace_all()] should be called
+#'   on double quotes.
 #' @param squish logical; whether [stringr::str_squish()] should be called.
 #' @return A normalized vector of the same length.
 #' @examples
@@ -19,13 +20,12 @@
 #' @importFrom stringr str_to_upper str_replace_all str_squish
 #' @family geographic normalization functions
 #' @export
-str_normal <- function(x, case = TRUE, punct = TRUE, quote = TRUE, squish = TRUE) {
+str_normal <- function(x, case = TRUE, punct = "", quote = TRUE, squish = TRUE) {
   if (case) {
     x <- stringr::str_to_upper(x)
   }
-  if (punct) {
-    x <- stringr::str_replace_all(x, "[[:punct:]]", " ")
-    x <- stringr::str_replace_all(x, "&", "AND")
+  if (is.character(punct)) {
+    x <- stringr::str_replace_all(x, "[[[:punct:]]-[#/]]", punct)
   }
   if (quote) {
     x <- stringr::str_replace_all(x, "\"", "\'")
