@@ -3,5 +3,5 @@ library(campfin)
 
 test_that("diary creation works", {
   x <- use_diary("VT", "expends", "Kiernan Nicholls", FALSE)
-  expect_length(x, 623)
+  expect_type(x, "character")
 })
